using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using BlockIOSDK;

namespace BlockIO5024
{
    public partial class Form1 : Form
    {
        private IntPtr mHandle;
        public Form1()
        {
            InitializeComponent();
        }

        private void Open_Click(object sender, EventArgs e)
        {
            if (IA.Text == "")
            {
                MessageBox.Show("Please input IP address!!");
                return;
            }

            //install
            btnOpen.Enabled = false;
            uint dwRet = BlockIOAPIr.SYS_Install(out mHandle, IA.Text);
            if ((dwRet & 0xFF) != 0)
            {
                dwRet = dwRet & 0xFF;
                MessageBox.Show(String.Format("Function SYS_Install returns error code: {0}!", dwRet));
                btnOpen.Enabled = true;
                return;
            }
            btnClose.Enabled = true;
            //

            //get module's name
            StringBuilder ss = new StringBuilder(20);
            BlockIOAPIr.SYS_GetModuleName(mHandle, ss, 20);
            MN.Text = ss.ToString();
            //

            //get module's firmware version
            StringBuilder ss1 = new StringBuilder(20);
            BlockIOAPIr.SYS_GetModuleFirmware(mHandle, ss1, 20);
            FV.Text = ss1.ToString();
            //

            //get slew rate and output range
            I5024_PARAM param;
            uint ret = BlockIO5024r.AO_GetConfig(mHandle, out param);
            //            cSlewRate.SelectedIndex = param.bySlewRates[0];
            cOutputRange.SelectedIndex = param.byOutputRanges[0];
            cSlewRate.Items.Clear();
            if (0 == cOutputRange.SelectedIndex)
            {
                cSlewRate.Items.Add("immediate change");
                cSlewRate.Items.Add("0.0625");
                cSlewRate.Items.Add("0.125");
                cSlewRate.Items.Add("0.25");
                cSlewRate.Items.Add("0.5");
                cSlewRate.Items.Add("1.0");
                cSlewRate.Items.Add("2.0");
                cSlewRate.Items.Add("4.0");
                cSlewRate.Items.Add("8.0");
                cSlewRate.Items.Add("16.0");
                cSlewRate.Items.Add("32.0");
                cSlewRate.Items.Add("64.0");
            }
            else
            {
                cSlewRate.Items.Add("immediate change");
                cSlewRate.Items.Add("0.125");
                cSlewRate.Items.Add("0.25");
                cSlewRate.Items.Add("0.5");
                cSlewRate.Items.Add("1.0");
                cSlewRate.Items.Add("2.0");
                cSlewRate.Items.Add("4.0");
                cSlewRate.Items.Add("8.0");
                cSlewRate.Items.Add("16.0");
                cSlewRate.Items.Add("32.0");
                cSlewRate.Items.Add("64.0");
                cSlewRate.Items.Add("128.0");
            }
            cSlewRate.SelectedIndex = param.bySlewRates[0];
            cSlewRate.Enabled = true;
            cOutputRange.Enabled = true;
            btnUpdateIR.Enabled = true;
            //

            //get watchdog config
            bool Enable;
            double WDTimer;
            BlockIOAPIr.SYS_GetWatchDogConfig(mHandle, out Enable, out WDTimer);
            WD.Checked = Enable;
            WDT.Text = String.Format("{0}", WDTimer);
            WD.Enabled = true;
            WDT.Enabled = true;
            btnUpdateWD.Enabled = true;
            //

            //enable channel
            tbAO0.Enabled = true;
            btnAO0.Enabled = true;
            btnSP0.Enabled = true;
            tbAO1.Enabled = true;
            btnAO1.Enabled = true;
            btnSP1.Enabled = true;
            tbAO2.Enabled = true;
            btnAO2.Enabled = true;
            btnSP2.Enabled = true;
            tbAO3.Enabled = true;
            btnAO3.Enabled = true;
            btnSP3.Enabled = true;
            //

            timer1.Enabled = true;
        }

        private void btnClose_Click(object sender, EventArgs e)
        {
            timer1.Enabled = false;

            btnClose.Enabled = false;

            BlockIOAPIr.SYS_Release(mHandle);

            //reset AO
            tbAO0.Enabled = false;
            tbAO0.Text = "";
            btnAO0.Enabled = false;
            tbV0.Text = "";
            btnSP0.Enabled = false;

            tbAO1.Enabled = false;
            tbAO1.Text = "";
            btnAO1.Enabled = false;
            tbV1.Text = "";
            btnSP1.Enabled = false;

            tbAO2.Enabled = false;
            tbAO2.Text = "";
            btnAO2.Enabled = false;
            tbV2.Text = "";
            btnSP2.Enabled = false;

            tbAO3.Enabled = false;
            tbAO3.Text = "";
            btnAO3.Enabled = false;
            tbV3.Text = "";
            btnSP3.Enabled = false;
            //

            //reset watch dlg
            btnUpdateWD.Enabled = false;
            WDT.Enabled = false;
            WDT.Text = "";
            WD.Enabled = false;
            WD.Checked = false;
            //

            //reset slew rate
            cSlewRate.Enabled = false;
            cSlewRate.SelectedIndex = -1;
            cOutputRange.Enabled = false;
            cOutputRange.SelectedIndex = -1;
            btnUpdateIR.Enabled = false;

            //reset others
            FV.Text = "";
            MN.Text = "";
            //

            btnOpen.Enabled = true;
        }


        private void btnUpdate_Click(object sender, EventArgs e)
        {
            BlockIOAPIr.SYS_SetWatchDogConfig(mHandle, WD.Checked, Convert.ToSingle(WDT.Text));
        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            double[] dblVal = new double[4];

            uint ret = BlockIO5024r.AO_GetAO(mHandle, 255, dblVal);
            tbV0.Text = String.Format("{0}", dblVal[0]);
            tbV1.Text = String.Format("{0}", dblVal[1]);
            tbV2.Text = String.Format("{0}", dblVal[2]);
            tbV3.Text = String.Format("{0}", dblVal[3]);
        }

        private void btnUpdateIR_Click(object sender, EventArgs e)
        {
            I5024_PARAM param = new I5024_PARAM();
            param.bySlewRates = new byte[4];
            param.byOutputRanges = new byte[4];
            param.bySlewRates[0] = (byte)cSlewRate.SelectedIndex;
            param.bySlewRates[1] = (byte)cSlewRate.SelectedIndex;
            param.bySlewRates[2] = (byte)cSlewRate.SelectedIndex;
            param.bySlewRates[3] = (byte)cSlewRate.SelectedIndex;
            param.byOutputRanges[0] = (byte)cOutputRange.SelectedIndex;
            param.byOutputRanges[1] = (byte)cOutputRange.SelectedIndex;
            param.byOutputRanges[2] = (byte)cOutputRange.SelectedIndex;
            param.byOutputRanges[3] = (byte)cOutputRange.SelectedIndex;
            param.byMask = 3;

            uint ret = BlockIO5024r.AO_SetConfig(mHandle, ref param);
        }

        private void btnAO0_Click(object sender, EventArgs e)
        {
            BlockIO5024r.AO_SetAO(mHandle, 0, Convert.ToSingle(tbAO0.Text));
        }

        private void btnAO1_Click(object sender, EventArgs e)
        {
            BlockIO5024r.AO_SetAO(mHandle, 1, Convert.ToSingle(tbAO1.Text));
        }

        private void btnAO2_Click(object sender, EventArgs e)
        {
            BlockIO5024r.AO_SetAO(mHandle, 2, Convert.ToSingle(tbAO2.Text));
        }

        private void btnAO3_Click(object sender, EventArgs e)
        {
            BlockIO5024r.AO_SetAO(mHandle, 3, Convert.ToSingle(tbAO3.Text));
        }

        private void btnSP0_Click(object sender, EventArgs e)
        {
            BlockIO5024r.AO_SetPowerOnValue(mHandle, 0);
        }

        private void btnSP1_Click(object sender, EventArgs e)
        {
            BlockIO5024r.AO_SetPowerOnValue(mHandle, 1);
        }

        private void btnSP2_Click(object sender, EventArgs e)
        {
            BlockIO5024r.AO_SetPowerOnValue(mHandle, 2);
        }

        private void btnSP3_Click(object sender, EventArgs e)
        {
            BlockIO5024r.AO_SetPowerOnValue(mHandle, 3);
        }

        private void Form1_FormClosed(object sender, FormClosedEventArgs e)
        {
            if (mHandle.ToInt32() > 0) BlockIOAPIr.SYS_Release(mHandle);
        }

        private void cOutputRange_SelectedIndexChanged(object sender, EventArgs e)
        {
            int nSel = cSlewRate.SelectedIndex;
            cSlewRate.Items.Clear();
            if (0 == cOutputRange.SelectedIndex)
            {
                cSlewRate.Items.Add("immediate change");
                cSlewRate.Items.Add("0.0625");
                cSlewRate.Items.Add("0.125");
                cSlewRate.Items.Add("0.25");
                cSlewRate.Items.Add("0.5");
                cSlewRate.Items.Add("1.0");
                cSlewRate.Items.Add("2.0");
                cSlewRate.Items.Add("4.0");
                cSlewRate.Items.Add("8.0");
                cSlewRate.Items.Add("16.0");
                cSlewRate.Items.Add("32.0");
                cSlewRate.Items.Add("64.0");
            }
            else
            {
                cSlewRate.Items.Add("immediate change");
                cSlewRate.Items.Add("0.125");
                cSlewRate.Items.Add("0.25");
                cSlewRate.Items.Add("0.5");
                cSlewRate.Items.Add("1.0");
                cSlewRate.Items.Add("2.0");
                cSlewRate.Items.Add("4.0");
                cSlewRate.Items.Add("8.0");
                cSlewRate.Items.Add("16.0");
                cSlewRate.Items.Add("32.0");
                cSlewRate.Items.Add("64.0");
                cSlewRate.Items.Add("128.0");
            }
            cSlewRate.SelectedIndex = nSel;
        }
    }
}