using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using BlockIOSDK;

namespace BlockIO5014
{
    public partial class Form1 : Form
    {
        private IntPtr mHandle;
        public Form1()
        {
            InitializeComponent();
        }

        private void Open_Click(object sender, EventArgs e)
        {
            if (IA.Text == "")
            {
                MessageBox.Show("Please input IP address!!");
                return;
            }

            //install
            btnOpen.Enabled = false;
            uint dwRet = BlockIOAPIr.SYS_Install(out mHandle, IA.Text);
            if ((dwRet & 0xFF) != 0)
            {
                dwRet = dwRet & 0xFF;
                MessageBox.Show(String.Format("Function SYS_Install returns error code: {0}!", dwRet));
                btnOpen.Enabled = true;
                return;
            }
            btnClose.Enabled = true;
            //

            //get module's name
            StringBuilder ss = new StringBuilder(20);
            BlockIOAPIr.SYS_GetModuleName(mHandle, ss, 20);
            MN.Text = ss.ToString();
            //

            //get module's firmware version
            StringBuilder ss1 = new StringBuilder(20);
            BlockIOAPIr.SYS_GetModuleFirmware(mHandle, ss1, 20);
            FV.Text = ss1.ToString();
            //
            /*
            Input code (address low)  
            Code:20H~28H  
            20H:  pt100 ( -100~ 100 =0.00385)
            21H:  pt100 ( 0~ 100 =0.00385)
            22H:  pt100 ( 0~ 200 =0.00385)
            23H:  pt100 ( 0~ 600 =0.00385)
            24H:  pt100 ( -100~ 100 =0.00392)
            25H:  pt100 ( 0~ 100 =0.00392)
            26H:  pt100 ( 0~ 200 =0.00392)
            27H:  pt100 ( 0~ 600 =0.00392)
            28H:  Nickel 120( -80 ~ 260 =0.00672 )
            */
            //get input range
            byte byIR;
            BlockIO5014r.RTD_GetInputRange(mHandle, out byIR);
            byIR -= 0x20;
            IR.SelectedIndex = byIR;
            IR.Enabled = true;
            btnUpdateIR.Enabled = true;
            //

            //get watchdog config
            bool Enable;
            double WDTimer;
            BlockIOAPIr.SYS_GetWatchDogConfig(mHandle, out Enable, out WDTimer);
            WD.Checked = Enable;
            WDT.Text = String.Format("{0}", WDTimer);
            WD.Enabled = true;
            WDT.Enabled = true;
            btnUpdateWD.Enabled = true;
            //

            //get channel status
            byte byStatus;
            BlockIO5014r.RTD_GetChannelStatus(mHandle, out byStatus);
            cb0.Enabled = true;
            if ((byStatus & 1) > 0)
            {
                cb0.Checked = true;
                tb0.Enabled = true;
            }
            cb1.Enabled = true;
            if ((byStatus & 2) > 0)
            {
                cb1.Checked = true;
                tb1.Enabled = true;
            }
            cb2.Enabled = true;
            if ((byStatus & 4) > 0)
            {
                cb2.Checked = true;
                tb2.Enabled = true;
            }
            cb3.Enabled = true;
            if ((byStatus & 8) > 0)
            {
                cb3.Checked = true;
                tb3.Enabled = true;
            }
           
            timer1.Enabled = true;
            //
        }

        private void btnClose_Click(object sender, EventArgs e)
        {
            timer1.Enabled = false;

            btnClose.Enabled = false;

            BlockIOAPIr.SYS_Release(mHandle);

            //reset channel
            tb0.Enabled = false;
            tb1.Enabled = false;
            tb2.Enabled = false;
            tb3.Enabled = false;

            tb0.Text = "";
            tb1.Text = "";
            tb2.Text = "";
            tb3.Text = "";

            cb0.Enabled = false;
            cb1.Enabled = false;
            cb2.Enabled = false;
            cb3.Enabled = false;
  
            cb0.Checked = false;
            cb1.Checked = false;
            cb2.Checked = false;
            cb3.Checked = false;
            //

            //reset watch dlg
            btnUpdateWD.Enabled = false;
            WDT.Enabled = false;
            WDT.Text = "";
            WD.Enabled = false;
            WD.Checked = false;
            //

            //reset others
            btnUpdateIR.Enabled = false;
            IR.Enabled = false;
            IR.Text = "";
            FV.Text = "";
            MN.Text = "";
            //

            btnOpen.Enabled = true;
        }

 
        private void btnUpdate_Click(object sender, EventArgs e)
        {
            BlockIOAPIr.SYS_SetWatchDogConfig(mHandle, WD.Checked, Convert.ToSingle(WDT.Text));
        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            double dblAI;
            if (cb0.Checked)
            {
                BlockIO5014r.RTD_GetAI(mHandle, 0, out dblAI);
                tb0.Text = String.Format("{0}", dblAI);
            }
            if (cb1.Checked)
            {
                BlockIO5014r.RTD_GetAI(mHandle, 1, out dblAI);
                tb1.Text = String.Format("{0}", dblAI);
            }
            if (cb2.Checked)
            {
                BlockIO5014r.RTD_GetAI(mHandle, 2, out dblAI);
                tb2.Text = String.Format("{0}", dblAI);
            }
            if (cb3.Checked)
            {
                BlockIO5014r.RTD_GetAI(mHandle, 3, out dblAI);
                tb3.Text = String.Format("{0}", dblAI);
            }
        }

        private void btnUpdateIR_Click(object sender, EventArgs e)
        {
            byte nSel = (byte)IR.SelectedIndex;
            nSel += 0x20;
            BlockIO5014r.RTD_SetInputRange(mHandle, nSel);
        }

        private void cb0_CheckedChanged(object sender, EventArgs e)
        {
            if (cb0.Checked)
            {
                BlockIO5014r.RTD_SetChannelStatus(mHandle, 0, 1);
                tb0.Enabled = true;
            }
            else
            {
                BlockIO5014r.RTD_SetChannelStatus(mHandle, 0, 0);
                tb0.Enabled = false;
                tb0.Text = "";
            }
        }

        private void cb1_CheckedChanged(object sender, EventArgs e)
        {
            if (cb1.Checked)
            {
                BlockIO5014r.RTD_SetChannelStatus(mHandle, 1, 1);
                tb1.Enabled = true;
            }
            else
            {
                BlockIO5014r.RTD_SetChannelStatus(mHandle, 1, 0);
                tb1.Enabled = false;
                tb1.Text = "";
            }
        }

        private void cb2_CheckedChanged(object sender, EventArgs e)
        {
            if (cb2.Checked)
            {
                BlockIO5014r.RTD_SetChannelStatus(mHandle, 2, 1);
                tb2.Enabled = true;
            }
            else
            {
                BlockIO5014r.RTD_SetChannelStatus(mHandle, 2, 0);
                tb2.Enabled = false;
                tb2.Text = "";
            }
        }

        private void cb3_CheckedChanged(object sender, EventArgs e)
        {
            if (cb3.Checked)
            {
                BlockIO5014r.RTD_SetChannelStatus(mHandle, 3, 1);
                tb3.Enabled = true;
            }
            else
            {
                BlockIO5014r.RTD_SetChannelStatus(mHandle, 3, 0);
                tb3.Enabled = false;
                tb3.Text = "";
            }
        }

        private void Form1_FormClosed(object sender, FormClosedEventArgs e)
        {
            if (mHandle.ToInt32() > 0) BlockIOAPIr.SYS_Release(mHandle);
        }

    }
}