using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using BlockIOSDK;

namespace BlockIO5018
{
    public partial class Form1 : Form
    {
        private IntPtr mHandle;
        public Form1()
        {
            InitializeComponent();
            mHandle = new IntPtr(0);
        }

        private void Open_Click(object sender, EventArgs e)
        {
            if (IA.Text == "")
            {
                MessageBox.Show("Please input IP address!!");
                return;
            }

            //install
            btnOpen.Enabled = false;
            uint dwRet = BlockIOAPIr.SYS_Install(out mHandle, IA.Text);
            if ((dwRet & 0xFF) != 0)
            {
                dwRet = dwRet & 0xFF;
                MessageBox.Show(String.Format("Function SYS_Install returns error code: {0}!", dwRet));
                btnOpen.Enabled = true;
                return;
            }
            btnClose.Enabled = true;
            //

            //get module's name
            StringBuilder ss = new StringBuilder(20);
            BlockIOAPIr.SYS_GetModuleName(mHandle, ss, 20);
            MN.Text = ss.ToString();
            //

            //get module's firmware version
            StringBuilder ss1 = new StringBuilder(20);
            BlockIOAPIr.SYS_GetModuleFirmware(mHandle, ss1, 20);
            FV.Text = ss1.ToString();
            //
/*
Input range (address low)  
Code:08H~0DH  
00H: 15mV
01H: 50mV
02H: 100mV
03H: 500mV
04H: 1V
05H: 2.5V
06H: 20mA
0EH: J Type Thermocouple  
0FH: K Type Thermocouple  
10H: T Type Thermocouple  
11H: E Type Thermocouple  
12H: R Type Thermocouple  
13H: S Type Thermocouple 
14H: B Type Thermocouple 
15H: N Type Thermocouple  
16H: C Type Thermocouple 
*/
            //get input range
            byte byIR;
            BlockIO5018r.TC_GetInputRange(mHandle, out byIR);
            if (byIR >= 0x0E) byIR -= 7;
            IR.SelectedIndex = byIR;
            IR.Enabled = true;
            btnUpdateIR.Enabled = true;
            //

            //get watchdog config
            bool Enable;
            double WDTimer;
            BlockIOAPIr.SYS_GetWatchDogConfig(mHandle, out Enable, out WDTimer);
            WD.Checked = Enable;
            WDT.Text = String.Format("{0}", WDTimer);
            WD.Enabled = true;
            WDT.Enabled = true;
            btnUpdateWD.Enabled = true;
            //

            //get channel status
            byte byStatus;
            BlockIO5018r.TC_GetChannelStatus(mHandle, out byStatus);
            cb0.Enabled = true;
            if ((byStatus & 1) > 0)
            {
                cb0.Checked = true;
                tb0.Enabled = true;
            }
            cb1.Enabled = true;
            if ((byStatus & 2) > 0)
            {
                cb1.Checked = true;
                tb1.Enabled = true;
            }
            cb2.Enabled = true;
            if ((byStatus & 4) > 0)
            {
                cb2.Checked = true;
                tb2.Enabled = true;
            }
            cb3.Enabled = true;
            if ((byStatus & 8) > 0)
            {
                cb3.Checked = true;
                tb3.Enabled = true;
            }
            cb4.Enabled = true;
            if ((byStatus & 16) > 0)
            {
                cb4.Checked = true;
                tb4.Enabled = true;
            }
            cb5.Enabled = true;
            if ((byStatus & 32) > 0)
            {
                cb5.Checked = true;
                tb5.Enabled = true;
            }
            cb6.Enabled = true;
            if ((byStatus & 64) > 0)
            {
                cb6.Checked = true;
                tb6.Enabled = true;
            }
            cb7.Enabled = true;
            if ((byStatus & 128) > 0)
            {
                cb7.Checked = true;
                tb7.Enabled = true;
            }

            //enable cjc
            CJC.Enabled = true;
            Offset.Enabled = true;
            btnExecute.Enabled = true;

            timer1.Enabled = true;
            //
        }

        private void btnClose_Click(object sender, EventArgs e)
        {
            timer1.Enabled = false;

            btnClose.Enabled = false;

            BlockIOAPIr.SYS_Release(mHandle);
            mHandle = new IntPtr(0);

            //reset channel
            CJC.Enabled = false;
            CJC.Text = "";
            Offset.Enabled = false;
            Offset.Text = "";
            btnExecute.Enabled = false;

            tb0.Enabled = false;
            tb1.Enabled = false;
            tb2.Enabled = false;
            tb3.Enabled = false;
            tb4.Enabled = false;
            tb5.Enabled = false;
            tb6.Enabled = false;
            tb7.Enabled = false;
            tb0.Text = "";
            tb1.Text = "";
            tb2.Text = "";
            tb3.Text = "";
            tb4.Text = "";
            tb5.Text = "";
            tb6.Text = "";
            tb7.Text = "";
            cb0.Enabled = false;
            cb1.Enabled = false;
            cb2.Enabled = false;
            cb3.Enabled = false;
            cb4.Enabled = false;
            cb5.Enabled = false;
            cb6.Enabled = false;
            cb7.Enabled = false;
            cb0.Checked = false;
            cb1.Checked = false;
            cb2.Checked = false;
            cb3.Checked = false;
            cb4.Checked = false;
            cb5.Checked = false;
            cb6.Checked = false;
            cb7.Checked = false;
            //

            //reset watch dlg
            btnUpdateWD.Enabled = false;
            WDT.Enabled = false;
            WDT.Text = "";
            WD.Enabled = false;
            WD.Checked = false;
            //

            //reset others
            btnUpdateIR.Enabled = false;
            IR.Enabled = false;
            IR.SelectedIndex = -1;
            FV.Text = "";
            MN.Text = "";
            //

            btnOpen.Enabled = true;
        }

        private void btnUpdate_Click(object sender, EventArgs e)
        {
            BlockIOAPIr.SYS_SetWatchDogConfig(mHandle, WD.Checked, Convert.ToSingle(WDT.Text));
        }


        private void timer1_Tick(object sender, EventArgs e)
        {
            double dblAI;
            if (cb0.Checked)
            {
                BlockIO5018r.TC_GetAI(mHandle, 0, out dblAI);
                tb0.Text = String.Format("{0}", dblAI);
            }
            if (cb1.Checked)
            {
                BlockIO5018r.TC_GetAI(mHandle, 1, out dblAI);
                tb1.Text = String.Format("{0}", dblAI);
            }
            if (cb2.Checked)
            {
                BlockIO5018r.TC_GetAI(mHandle, 2, out dblAI);
                tb2.Text = String.Format("{0}", dblAI);
            }
            if (cb3.Checked)
            {
                BlockIO5018r.TC_GetAI(mHandle, 3, out dblAI);
                tb3.Text = String.Format("{0}", dblAI);
            }
            if (cb4.Checked)
            {
                BlockIO5018r.TC_GetAI(mHandle, 4, out dblAI);
                tb4.Text = String.Format("{0}", dblAI);
            }
            if (cb5.Checked)
            {
                BlockIO5018r.TC_GetAI(mHandle, 5, out dblAI);
                tb5.Text = String.Format("{0}", dblAI);
            }
            if (cb6.Checked)
            {
                BlockIO5018r.TC_GetAI(mHandle, 6, out dblAI);
                tb6.Text = String.Format("{0}", dblAI);
            }
            if (cb7.Checked)
            {
                BlockIO5018r.TC_GetAI(mHandle, 7, out dblAI);
                tb7.Text = String.Format("{0}", dblAI);
            }
            //cjc
            BlockIO5018r.TC_GetCJCValue(mHandle, out dblAI);
            CJC.Text = String.Format("{0}", dblAI);
        }

        private void btnUpdateIR_Click(object sender, EventArgs e)
        {
            byte nSel = (byte)IR.SelectedIndex;
            if (nSel >= 7) nSel += 7;
            BlockIO5018r.TC_SetInputRange(mHandle, nSel);
        }

        private void btnExecute_Click(object sender, EventArgs e)
        {
            BlockIO5018r.TC_SetCJCOffset(mHandle, Convert.ToSingle(Offset.Text));
            BlockIO5018r.TC_CalibrateCJC(mHandle);
        }

        private void cb0_CheckedChanged(object sender, EventArgs e)
        {
            if (!btnClose.Enabled) return; //return if closed

            if (cb0.Checked)
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 0, 1);
                tb0.Enabled = true;
            }
            else
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 0, 0);
                tb0.Enabled = false;
                tb0.Text = "";
            }
        }

        private void cb1_CheckedChanged(object sender, EventArgs e)
        {
            if (!btnClose.Enabled) return;

            if (cb1.Checked)
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 1, 1);
                tb1.Enabled = true;
            }
            else
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 1, 0);
                tb1.Enabled = false;
                tb1.Text = "";
            }
        }

        private void cb2_CheckedChanged(object sender, EventArgs e)
        {
            if (!btnClose.Enabled) return;

            if (cb2.Checked)
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 2, 1);
                tb2.Enabled = true;
            }
            else
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 2, 0);
                tb2.Enabled = false;
                tb2.Text = "";
            }
        }

        private void cb3_CheckedChanged(object sender, EventArgs e)
        {
            if (!btnClose.Enabled) return;

            if (cb3.Checked)
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 3, 1);
                tb3.Enabled = true;
            }
            else
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 3, 0);
                tb3.Enabled = false;
                tb3.Text = "";
            }
        }

        private void cb4_CheckedChanged(object sender, EventArgs e)
        {
            if (!btnClose.Enabled) return;

            if (cb4.Checked)
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 4, 1);
                tb4.Enabled = true;
            }
            else
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 4, 0);
                tb4.Enabled = false;
                tb4.Text = "";
            }
        }

        private void cb5_CheckedChanged(object sender, EventArgs e)
        {
            if (!btnClose.Enabled) return;

            if (cb5.Checked)
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 5, 1);
                tb5.Enabled = true;
            }
            else
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 5, 0);
                tb5.Enabled = false;
                tb5.Text = "";
            }
        }

        private void cb6_CheckedChanged(object sender, EventArgs e)
        {
            if (!btnClose.Enabled) return;

            if (cb6.Checked)
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 6, 1);
                tb6.Enabled = true;
            }
            else
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 6, 0);
                tb6.Enabled = false;
                tb6.Text = "";
            }
        }

        private void cb7_CheckedChanged(object sender, EventArgs e)
        {
            if (!btnClose.Enabled) return;

            if (cb7.Checked)
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 7, 1);
                tb7.Enabled = true;
            }
            else
            {
                BlockIO5018r.TC_SetChannelStatus(mHandle, 7, 0);
                tb7.Enabled = false;
                tb7.Text = "";
            }
        }

        private void Form1_FormClosed(object sender, FormClosedEventArgs e)
        {
            if (mHandle.ToInt32() > 0) BlockIOAPIr.SYS_Release(mHandle);
        }
    }
}